<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Product_db extends CI_Model {

	function __construct()
    {
        parent::__construct();
        $this->load->database();
    }

    public function getAllProducts()
    {
        /*
        * getAllProducts
        *
        * This Function returns all Products from Dtabase as an Array
        *
        * @return Products in array
        */

        $this->db->from('products');
        $this->db->join('unittable', 'products.unit = unittable.unitid', 'Left');
        $this->db->join('categorytable', 'products.category = categorytable.categoryid', 'Left');
        $this->db->order_by('expiredate', 'ASC');
        $result = $this->db->get();

        //$result = $this->db->get('products');

        return $result->result();
    }

    public function getProductById($product_id)
    {
        $result = $this->db->get_where('products', array('productid' => $product_id));
        return $result->result();   
    }

    public function createProduct($product_array)
    {
        /*
        * createProduct
        *
        * This Function adds the new Product and return the ID from the created Database Item
        *
        * @param array $product_array Product data Array from the Controller
        * @return int New insert_id()
        */

        $this->db->insert('products', $product_array);

        return $this->db->insert_id();
    }

    public function removeProductById($product_id)
    {
        /*
        * Remove Product by ID
        *
        * This Function will remove an existing Product by ID.
        *
        * @param int $product_id - The ID from the current product, must correspond with the Product ID in the Database
        * @return string ID is no int
        */

        if (!is_int($product_id)) {
            return "ID is no INT";
        }

        $product_id_array = array(
                'productid' => $product_id
        );

        $this->db->delete('products', $product_id_array);

        return "Product removed";
    }

    public function updateProductById($product_id, $product_data)
    {
        /*
        * Update Product by ID
        *
        * This Function update the Product with the ID. After that, the state will returned
        *
        * @param int $product_id -T ID from the current product, must correspond with the Product ID in the Database
        * @param array $product_data - Contains the complet data array from the formular. The corrct allocation will do the model.
        * @return TRUE FALSE
        */
        $product_id_array = array(
                'productid' => $product_id
        );

        

        return $this->db->update('products', $product_data, $product_id_array);
    }

    public function updateNumberOfProductByIdPlus($product_id)
    {
        /*
        * Update Product by ID
        *
        * This Function update the Product with the ID. After that, the state will returned
        *
        * @param int $product_id -T ID from the current product, must correspond with the Product ID in the Database
        * @param int $new_count - New product count. Not lower tha 0.
        * @return 1 for OK or 0 for an ERROR is happen
        */

        $product_id_array = array(
                'productid' => $product_id,
        );

        $this->db->set('numberofproduct', 'numberofproduct+1', FALSE);
        $this->db->where($product_id_array);
        $result = $this->db->update('products');

        if($result == 1)
        {
            
        }

        return $result;
    }

    public function updateNumberOfProductByIdMinus($product_id)
    {
        /*
        * Update Product by ID
        *
        * This Function update the Product with the ID. After that, the state will returned
        *
        * @param int $product_id -T ID from the current product, must correspond with the Product ID in the Database
        * @param int $new_count - New product count. Not lower tha 0.
        * @return 1 for OK or 0 for an ERROR is happen
        */

        $product_id_array = array(
                'productid' => $product_id,
        );

        $this->db->set('numberofproduct', 'numberofproduct-1', FALSE);
        $this->db->where($product_id_array);
        $result = $this->db->update('products');

        if($result == 1)
        {
            
        }

        return $result;
    }

    /**
     * 
     */
    function userhasproducts($memberid){
        $result = $this->db->get_where('products', array('createdby' => $memberid));
        return count($result->result());
    }
}






    /*
    * Update Product by ID
    *
    * This Function update the Product with the ID. After that, the state will returned
    *
    * @param int $product_id -T ID from the current product, must correspond with the Product ID in the Database
    * @param array $product_data - Contains the complet data array from the formular. The corrct allocation will do the model.
    * @return TRUE FALSE
    */